check_manifest_files: Checks that the files defined in the manifest exist
Description
Checks that the files defined in the manifest exist
Usage
check_manifest_files(my_manifest, file_dir)
Arguments
- my_manifest
A list with the contents of the manifest file.
- file_dir
Path to the directory where all the files have been extracted.